Security Token Manager is an open source project that provides a command line tool and API library to interact and integrate tokens to your business systems.


.. image:: https://badges.gitter.im/TokenMarketNet/sto.svg
   :alt: Join the chat at https://gitter.im/security-token/Lobby
   :target: https://gitter.im/security-token/Lobby

.. image:: https://img.shields.io/travis/TokenMarketNet/sto.svg
        :target: https://travis-ci.org/TokenMarketNet/sto


TokenMarket Security Token Manager
==================================

Security Token Manager provides technical operations for corporate governance including e.g.

* Issue out new stock series as security tokens

* Distributing shares to primary market investors

* Printing out cap table

* Managing bad transactions and lost privat keys

* Paying dividends and interest

* Delivering voting ballots

* Maintaining audit logs of delivered actions

The command line tool is locally installed via Docker and available for Windows, OSX and Linux. The API is written in Python programming language.

Get started
===========

* `Read an introduction for security tokens <https://tokenmarket.net/news/security-tokens/what-are-security-tokens/>`_

* `Read the documentation <https://docs.tokenmarket.net/>`_

Links
=====

`TokenMarket website <https://tokenmarket.net>`_

`Twitter <http://twitter.com/tokenmarkett>`_

`Documentation <https://docs.tokenmarket.net/>`_

`Github Source code and issue tracker <https://github.com/tokenmarketnet/sto>`_

`Support and chat <https://gitter.im/security-token/Lobby>`_

`Docker releases <https://hub.docker.com/r/miohtama/sto/>`_

`Python releases <https://pypi.org/project/sto/>`_

`Smart contracts repository <http://github.com/tokenmarketnet/ico>`_

`Change history <https://github.com/TokenMarketNet/sto/blob/master/CHANGES.rst>`_









